@@ -1,3 +1,3 @@
 from .mixins import RelayModelMixin
-from .pagination import CursorPage, CursorPaginator, InternalPaginator
+from .pagination import CursorPage, CursorPaginator, InternalPaginator, InvalidCursor
 from .resolvers import RelayModelResolver, page_info_resolver
